Crate chik_sdk_types

Crate chik_sdk_types 

Modules

conditions
puzzles

Structs

Compilation
Conditions
A grow-only list of conditions which can be used when building spend bundles.
MerkleProof
A proof for a leaf in a merkle tree. This is a KLVM type that can be passed in the solution of puzzles.
MerkleTree
A merkle tree implementation that can be used to prove the existence of a set of leaves. The proof format is compatible with standard Chik puzzles, such as p2_1_of_n.clsp.

Enums

Condition
LoadKlvmError

Statics

MAINNET_CONSTANTS
The consensus constants used on Chik’s mainnet network. Mainnet should be used for production applications.
TESTNET11_CONSTANTS
The consensus constants used on Chik’s testnet11 network. Testnet11 should be used for development applications.

Traits

Mod
This trait makes it possible to get the mod hash or puzzle reveal of a puzzle.

Functions

announcement_id
Creates announcement ids compatible with AssertCoinAnnouncement and AssertPuzzleAnnouncement.
default_constants
Used to compute the default constants used by Chik’s mainnet network, with a custom genesis_challenge and agg_sig_me_additional_data.
load_klvm
run_puzzle