Modules
Structs
- Compilation
- Conditions
- A grow-only list of conditions which can be used when building spend bundles.
- Merkle
Proof - A proof for a leaf in a merkle tree. This is a KLVM type that can be passed in the solution of puzzles.
- Merkle
Tree - A merkle tree implementation that can be used to prove the existence of a set of leaves.
The proof format is compatible with standard Chik puzzles, such as
p2_1_of_n.clsp.
Enums
Statics
- MAINNET_
CONSTANTS - The consensus constants used on Chik’s mainnet network. Mainnet should be used for production applications.
- TESTNE
T11_ CONSTANTS - The consensus constants used on Chik’s testnet11 network. Testnet11 should be used for development applications.
Traits
- Mod
- This trait makes it possible to get the mod hash or puzzle reveal of a puzzle.
Functions
- announcement_
id - Creates announcement ids compatible with
AssertCoinAnnouncementandAssertPuzzleAnnouncement. - default_
constants - Used to compute the default constants used by Chik’s mainnet network, with a custom
genesis_challengeandagg_sig_me_additional_data. - load_
klvm - run_
puzzle